summaryrefslogtreecommitdiffstats
path: root/kdat/IndexDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/IndexDlg.h')
-rw-r--r--kdat/IndexDlg.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kdat/IndexDlg.h b/kdat/IndexDlg.h
index 5b237c8..9dfd6ea 100644
--- a/kdat/IndexDlg.h
+++ b/kdat/IndexDlg.h
@@ -34,10 +34,11 @@ class Tape;
class TarParser;
/**
- * @short Status dialog for recreating a tape index.
+ * @short tqStatus dialog for recreating a tape index.
*/
class IndexDlg : public TQDialog {
Q_OBJECT
+ TQ_OBJECT
TarParser* _tarParser;
Tape* _tape;
Archive* _archive;
@@ -78,10 +79,10 @@ public:
* Create a new tape index dialog.
*
* @param tape A pointer to the empty tape index to fill in.
* @param parent The parent widget for this dialog.
* @param name The name of this dialog.
*/
- IndexDlg( Tape* tape, TQWidget* parent = 0, const char* name = 0 );
+ IndexDlg( Tape* tape, TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the tape index dialog.
@@ -78,10 +79,10 @@ public:
*
* @param tape A pointer to the empty tape index to fill in.
- * @param parent The parent widget for this dialog.
+ * @param tqparent The tqparent widget for this dialog.
* @param name The name of this dialog.
*/